% Auto-generated chapter 40 for bukhari
% Hadiths in this chapter: 18

\hadithdefcmd{bukhari}{2299}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَتَصَدَّقَ بِجِلاَلِ الْبُدْنِ الَّتِي نُحِرَتْ وَبِجُلُودِهَا‏.‏\hadithno{2299}\hadithtrans{Narrated `Ali:Allah's Messenger (ﷺ) ordered me to distribute the saddles and skins of the Budn which I had slaughtered}}
\hadithdefcmd{bukhari}{2300}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ غَنَمًا يَقْسِمُهَا عَلَى صَحَابَتِهِ، فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "ضَحِّ بِهِ أَنْتَ\hadithno{2300}\hadithtrans{Narrated `Uqba bin Amir:that the Prophet (ﷺ) had given him sheep to distribute among his companions and a male kid was left (after the distribution). When he informed the Prophet (ﷺ) of it, he said (to him), "Offer it as a sacrifice on your behalf}}
\hadithdefcmd{bukhari}{2301}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي يُوسُفُ بْنُ الْمَاجِشُونِ، عَنْ صَالِحِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ـ رضى الله عنه ـ قَالَ كَاتَبْتُ أُمَيَّةَ بْنَ خَلَفٍ كِتَابًا بِأَنْ يَحْفَظَنِي فِي صَاغِيَتِي بِمَكَّةَ، وَأَحْفَظَهُ فِي صَاغِيَتِهِ بِالْمَدِينَةِ، فَلَمَّا ذَكَرْتُ الرَّحْمَنَ قَالَ لاَ أَعْرِفُ الرَّحْمَنَ، كَاتِبْنِي بِاسْمِكَ الَّذِي كَانَ فِي الْجَاهِلِيَّةِ‏.‏ فَكَاتَبْتُهُ عَبْدُ عَمْرٍو فَلَمَّا كَانَ فِي يَوْمِ بَدْرٍ خَرَجْتُ إِلَى جَبَلٍ لأُحْرِزَهُ حِينَ نَامَ النَّاسُ فَأَبْصَرَهُ بِلاَلٌ فَخَرَجَ حَتَّى وَقَفَ عَلَى مَجْلِسٍ مِنَ الأَنْصَارِ فَقَالَ أُمَيَّةُ بْنُ خَلَفٍ، لاَ نَجَوْتُ إِنْ نَجَا أُمَيَّةُ‏.‏ فَخَرَجَ مَعَهُ فَرِيقٌ مِنَ الأَنْصَارِ فِي آثَارِنَا، فَلَمَّا خَشِيتُ أَنْ يَلْحَقُونَا خَلَّفْتُ لَهُمُ ابْنَهُ، لأَشْغَلَهُمْ فَقَتَلُوهُ ثُمَّ أَبَوْا حَتَّى يَتْبَعُونَا، وَكَانَ رَجُلاً ثَقِيلاً، فَلَمَّا أَدْرَكُونَا قُلْتُ لَهُ ابْرُكْ‏.‏ فَبَرَكَ، فَأَلْقَيْتُ عَلَيْهِ نَفْسِي لأَمْنَعَهُ، فَتَخَلَّلُوهُ بِالسُّيُوفِ مِنْ تَحْتِي، حَتَّى قَتَلُوهُ، وَأَصَابَ أَحَدُهُمْ رِجْلِي بِسَيْفِهِ، وَكَانَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ يُرِينَا ذَلِكَ الأَثَرَ فِي ظَهْرِ قَدَمِهِ‏.‏ قَالَ أَبُو عَبْد اللَّهِ سَمِعَ يُوسُفُ صَالِحًا وَإِبْرَاهِيمُ أَبَاهُ\hadithno{2301}\hadithtrans{Narrated `Abdur-Rahman bin `Auf:I got an agreement written between me and Umaiya bin Khalaf that Umaiya would look after my property (or family) in Mecca and I would look after his in Medina. When I mentioned the word 'Ar-Rahman' in the documents, Umaiya said, "I do not know 'Ar-Rahman.' Write down to me your name, (with which you called yourself) in the Pre-Islamic Period of Ignorance." So, I wrote my name ' `Abdu `Amr'. On the day (of the battle) of Badr, when all the people went to sleep, I went up the hill to protect him. Bilal(1) saw him (i.e. Umaiya) and went to a gathering of Ansar and said, "(Here is) Umaiya bin Khalaf! Woe to me if he escapes!" So, a group of Ansar went out with Bilal to follow us (`Abdur-Rahman and Umaiya). Being afraid that they would catch us, I left Umaiya's son for them to keep them busy but the Ansar killed the son and insisted on following us. Umaiya was a fat man, and when they approached us, I told him to kneel down, and he knelt, and I laid myself on him to protect him, but the Ansar killed him by passing their swords underneath me, and one of them injured my foot with his sword. (The sub narrator said, " `Abdur-Rahman used to show us the trace of the wound on the back of his foot)}}
\hadithdefcmd{bukhari}{2303}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي، هُرَيْرَةَ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ، فَجَاءَهُمْ بِتَمْرٍ جَنِيبٍ فَقَالَ ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ فَقَالَ إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِالصَّاعَيْنِ، وَالصَّاعَيْنِ بِالثَّلاَثَةِ‏.‏ فَقَالَ ‏"‏ لاَ تَفْعَلْ، بِعِ الْجَمْعَ بِالدَّرَاهِمِ، ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏‏.‏ وَقَالَ فِي الْمِيزَانِ مِثْلَ ذَلِكَ‏.‏\hadithno{2303}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) employed someone as a governor at Khaibar. When the man came to Medina, he brought with him dates called Janib. The Prophet (ﷺ) asked him, "Are all the dates of Khaibar of this kind?" The man replied, "(No), we exchange two Sa's of bad dates for one Sa of this kind of dates (i.e. Janib), or exchange three Sa's for two." On that, the Prophet (ﷺ) said, "Don't do so, as it is a kind of usury (Riba) but sell the dates of inferior quality for money, and then buy Janib with the money". The Prophet said the same thing about dates sold by weight. (See Hadith No)}}
\hadithdefcmd{bukhari}{2304}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ الْمُعْتَمِرَ، أَنْبَأَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّهُ سَمِعَ ابْنَ كَعْبِ بْنِ مَالِكٍ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّهُ كَانَتْ لَهُمْ غَنَمٌ تَرْعَى بِسَلْعٍ، فَأَبْصَرَتْ جَارِيَةٌ لَنَا بِشَاةٍ مِنْ غَنَمِنَا مَوْتًا، فَكَسَرَتْ حَجَرًا فَذَبَحَتْهَا بِهِ، فَقَالَ لَهُمْ لاَ تَأْكُلُوا حَتَّى أَسْأَلَ النَّبِيَّ صلى الله عليه وسلم، أَوْ أُرْسِلَ إِلَى النَّبِيِّ صلى الله عليه وسلم مَنْ يَسْأَلُهُ‏.‏ وَأَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ ذَاكَ، أَوْ أَرْسَلَ، فَأَمَرَهُ بِأَكْلِهَا‏.‏ قَالَ عُبَيْدُ اللَّهِ فَيُعْجِبُنِي أَنَّهَا أَمَةٌ، وَأَنَّهَا ذَبَحَتْ‏.‏ تَابَعَهُ عَبْدَةُ عَنْ عُبَيْدِ اللَّهِ‏.‏\hadithno{2304}\hadithtrans{Narrated Ibn Ka`b bin Malik from his father:We had some sheep which used to graze at Sala'. One of our slavegirls saw a sheep dying and she broke a stone and slaughtered the sheep with it. My father said to the people, "Don't eat it till I ask the Prophet about it (or till I send somebody to ask the Prophet)." So, he asked or sent somebody to ask the Prophet, and the Prophet (ﷺ) permitted him to eat it. 'Ubaidullah (a sub-narrator) said, "I admire that girl, for though she was a slave-girl, she dared to slaughter the sheep}}
\hadithdefcmd{bukhari}{2305}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ لِرَجُلٍ عَلَى النَّبِيِّ صلى الله عليه وسلم سِنٌّ مِنَ الإِبِلِ فَجَاءَهُ يَتَقَاضَاهُ فَقَالَ ‏"‏ أَعْطُوهُ ‏"‏‏.‏ فَطَلَبُوا سِنَّهُ فَلَمْ يَجِدُوا لَهُ إِلاَّ سِنًّا فَوْقَهَا‏.‏ فَقَالَ ‏"‏ أَعْطُوهُ ‏"‏‏.‏ فَقَالَ أَوْفَيْتَنِي أَوْفَى اللَّهُ بِكَ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ خِيَارَكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2305}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) owed somebody a camel of a certain age. When he came to demand it back, the Prophet (ﷺ) said (to some people), "Give him (his due)." When the people searched for a camel of that age, they found none, but found a camel one year older. The Prophet (ﷺ) said, "Give (it to) him." On that, the man remarked, "You have given me my right in full. May Allah give you in full." The Prophet (ﷺ) said, "The best amongst you is the one who pays the rights of others generously}}
\hadithdefcmd{bukhari}{2306}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم يَتَقَاضَاهُ، فَأَغْلَظَ، فَهَمَّ بِهِ أَصْحَابُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعُوهُ فَإِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ أَعْطُوهُ سِنًّا مِثْلَ سِنِّهِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ لاَ نَجِدُ إِلاَّ أَمْثَلَ مِنْ سِنِّهِ‏.‏ فَقَالَ ‏"‏ أَعْطُوهُ فَإِنَّ مِنْ خَيْرِكُمْ أَحْسَنَكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2306}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) demanding his debts and behaved rudely. The companions of the Prophet (ﷺ) intended to harm him, but Allah's Messenger (ﷺ) said (to them), "Leave him, for the creditor (i.e. owner of a right) has the right to speak." Allah's Messenger (ﷺ) then said, "Give him a camel of the same age as that of his." The people said, "O Allah's Messenger (ﷺ)! There is only a camel that is older than his." Allah's Messenger (ﷺ) said, "Give (it to) him, for the best amongst you is he who pays the rights of others handsomely}}
\hadithdefcmd{bukhari}{2308}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ وَزَعَمَ عُرْوَةُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ‏.‏ فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ، وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِهِمْ ‏"‏‏.‏ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً، حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمُسْلِمِينَ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ قَدْ جَاءُونَا تَائِبِينَ، وَإِنِّي قَدْ رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ بِذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ قَدْ طَيَّبْنَا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِي ذَلِكَ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعُوا إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ قَدْ طَيَّبُوا وَأَذِنُوا‏.‏\hadithno{2308}\hadithtrans{Narrated Marwan bin Al-Hakam and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin after embracing Islam, came to Allah's Messenger (ﷺ), he got up. They appealed to him to return their properties and their captives. Allah's Messenger (ﷺ) said to them, "The most beloved statement to me is the true one. So, you have the option of restoring your properties or your captives, for I have delayed distributing them." The narrator added, Allah's Messenger (ﷺ) had been waiting for them for more than ten days on his return from Taif. When they realized that Allah's Apostle would return to them only one of two things, they said, "We choose our captives." So, Allah's Apostle got up in the gathering of the Muslims, praised Allah as He deserved, and said, "Then after! These brethren of yours have come to you with repentance and I see it proper to return their captives to them. So, whoever amongst you likes to do that as a favor, then he can do it, and whoever of you wants to stick to his share till we pay him from the very first booty which Allah will give us then he can do so." The people replied, "We agree to give up our shares willingly as a favor for Allah's Apostle." Then Allah's Messenger (ﷺ) said, "We don't know who amongst you has agreed and who hasn't. Go back and your chiefs may tell us your opinion." So, all of them returned and their chiefs discussed the matter with them and then they (i.e. their chiefs) came to Allah's Messenger (ﷺ) to tell him that they (i.e. the people) had given up their shares gladly and willingly}}
\hadithdefcmd{bukhari}{2309}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، وَغَيْرِهِ،، يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ، وَلَمْ يُبَلِّغْهُ كُلُّهُمْ رَجُلٌ وَاحِدٌ مِنْهُمْ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ، فَكُنْتُ عَلَى جَمَلٍ ثَفَالٍ، إِنَّمَا هُوَ فِي آخِرِ الْقَوْمِ، فَمَرَّ بِي النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏‏.‏ قُلْتُ جَابِرُ بْنُ عَبْدِ اللَّهِ‏.‏ قَالَ ‏"‏ مَا لَكَ ‏"‏‏.‏ قُلْتُ إِنِّي عَلَى جَمَلٍ ثَفَالٍ‏.‏ قَالَ ‏"‏ أَمَعَكَ قَضِيبٌ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ أَعْطِنِيهِ ‏"‏‏.‏ فَأَعْطَيْتُهُ فَضَرَبَهُ فَزَجَرَهُ، فَكَانَ مِنْ ذَلِكَ الْمَكَانِ مِنْ أَوَّلِ الْقَوْمِ قَالَ ‏"‏ بِعْنِيهِ ‏"‏‏.‏ فَقُلْتُ بَلْ هُوَ لَكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ بِعْنِيهِ قَدْ أَخَذْتُهُ بِأَرْبَعَةِ دَنَانِيرَ، وَلَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ ‏"‏‏.‏ فَلَمَّا دَنَوْنَا مِنَ الْمَدِينَةِ أَخَذْتُ أَرْتَحِلُ‏.‏ قَالَ ‏"‏ أَيْنَ تُرِيدُ ‏"‏‏.‏ قُلْتُ تَزَوَّجْتُ امْرَأَةً قَدْ خَلاَ مِنْهَا‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏‏.‏ قُلْتُ إِنَّ أَبِي تُوُفِّيَ وَتَرَكَ بَنَاتٍ، فَأَرَدْتُ أَنْ أَنْكِحَ امْرَأَةً قَدْ جَرَّبَتْ خَلاَ مِنْهَا‏.‏ قَالَ ‏"‏ فَذَلِكَ ‏"‏‏.‏ فَلَمَّا قَدِمْنَا الْمَدِينَةَ قَالَ ‏"‏ يَا بِلاَلُ اقْضِهِ وَزِدْهُ ‏"‏‏.‏ فَأَعْطَاهُ أَرْبَعَةَ دَنَانِيرَ، وَزَادَهُ قِيرَاطًا‏.‏ قَالَ جَابِرٌ لاَ تُفَارِقُنِي زِيَادَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَلَمْ يَكُنِ الْقِيرَاطُ يُفَارِقُ جِرَابَ جَابِرِ بْنِ عَبْدِ اللَّهِ‏.‏\hadithno{2309}\hadithtrans{Narrated Jabir bin `Abdullah:I was accompanying the Prophet (ﷺ) on a journey and was riding a slow camel that was lagging behind the others. The Prophet (ﷺ) passed by me and asked, "Who is this?" I replied, "Jabir bin `Abdullah." He asked, "What is the matter, (why are you late)?" I replied, "I am riding a slow camel." He asked, "Do you have a stick?" I replied in the affirmative. He said, "Give it to me." When I gave it to him, he beat the camel and rebuked it. Then that camel surpassed the others thenceforth. The Prophet (ﷺ) said, "Sell it to me." I replied, "It is (a gift) for you, O Allah's Messenger (ﷺ)." He said, "Sell it to me. I have bought it for four Dinars (gold pieces) and you can keep on riding it till Medina." When we approached Medina, I started going (towards my house). The Prophet (ﷺ) said, "Where are you going?" I said, "I have married a widow." He said, "Why have you not married a virgin to fondle with each other?" I said, "My father died and left daughters, so I decided to marry a widow (an experienced woman) (to look after them)." He said, "Well done." When we reached Medina, Allah's Messenger (ﷺ) said, "O Bilal, pay him (the price of the camel) and give him extra money." Bilal gave me four Dinars and one Qirat extra. (A sub-narrator said): Jabir added, "The extra Qirat of Allah's Messenger (ﷺ) never parted from me." The Qirat was always in Jabir bin `Abdullah's purse}}
\hadithdefcmd{bukhari}{2310}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَهَبْتُ لَكَ مِنْ نَفْسِي‏.‏ فَقَالَ رَجُلٌ زَوِّجْنِيهَا‏.‏ قَالَ ‏ "‏ قَدْ زَوَّجْنَاكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{2310}\hadithtrans{Narrated Sahl bin Sad: A woman came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I want to give up myself to you." A man said, "Marry her to me." The Prophet (ﷺ) said, "We agree to marry her to you with what you know of the Qur'an by heart}}
\hadithdefcmd{bukhari}{2311}{وَقَالَ عُثْمَانُ بْنُ الْهَيْثَمِ أَبُو عَمْرٍو حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ وَكَّلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِحِفْظِ زَكَاةِ رَمَضَانَ، فَأَتَانِي آتٍ فَجَعَلَ يَحْثُو مِنَ الطَّعَامِ، فَأَخَذْتُهُ، وَقُلْتُ وَاللَّهِ لأَرْفَعَنَّكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ إِنِّي مُحْتَاجٌ، وَعَلَىَّ عِيَالٌ، وَلِي حَاجَةٌ شَدِيدَةٌ‏.‏ قَالَ فَخَلَّيْتُ عَنْهُ فَأَصْبَحْتُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا أَبَا هُرَيْرَةَ مَا فَعَلَ أَسِيرُكَ الْبَارِحَةَ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ شَكَا حَاجَةً شَدِيدَةً وَعِيَالاً فَرَحِمْتُهُ، فَخَلَّيْتُ سَبِيلَهُ‏.‏ قَالَ ‏"‏ أَمَا إِنَّهُ قَدْ كَذَبَكَ وَسَيَعُودُ ‏"‏‏.‏ فَعَرَفْتُ أَنَّهُ سَيَعُودُ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّهُ سَيَعُودُ‏.‏ فَرَصَدْتُهُ فَجَاءَ يَحْثُو مِنَ الطَّعَامِ فَأَخَذْتُهُ فَقُلْتُ لأَرْفَعَنَّكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ دَعْنِي فَإِنِّي مُحْتَاجٌ، وَعَلَىَّ عِيَالٌ لاَ أَعُودُ، فَرَحِمْتُهُ، فَخَلَّيْتُ سَبِيلَهُ فَأَصْبَحْتُ، فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا هُرَيْرَةَ، مَا فَعَلَ أَسِيرُكَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ شَكَا حَاجَةً شَدِيدَةً وَعِيَالاً، فَرَحِمْتُهُ فَخَلَّيْتُ سَبِيلَهُ‏.‏ قَالَ ‏"‏ أَمَا إِنَّهُ قَدْ كَذَبَكَ وَسَيَعُودُ ‏"‏‏.‏ فَرَصَدْتُهُ الثَّالِثَةَ فَجَاءَ يَحْثُو مِنَ الطَّعَامِ، فَأَخَذْتُهُ فَقُلْتُ لأَرْفَعَنَّكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، وَهَذَا آخِرُ ثَلاَثِ مَرَّاتٍ أَنَّكَ تَزْعُمُ لاَ تَعُودُ ثُمَّ تَعُودُ‏.‏ قَالَ دَعْنِي أُعَلِّمْكَ كَلِمَاتٍ يَنْفَعُكَ اللَّهُ بِهَا‏.‏ قُلْتُ مَا هُوَ قَالَ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَاقْرَأْ آيَةَ الْكُرْسِيِّ ‏\{‏اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ‏\}‏ حَتَّى تَخْتِمَ الآيَةَ، فَإِنَّكَ لَنْ يَزَالَ عَلَيْكَ مِنَ اللَّهِ حَافِظٌ وَلاَ يَقْرَبَنَّكَ شَيْطَانٌ حَتَّى تُصْبِحَ‏.‏ فَخَلَّيْتُ سَبِيلَهُ فَأَصْبَحْتُ، فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا فَعَلَ أَسِيرُكَ الْبَارِحَةَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ زَعَمَ أَنَّهُ يُعَلِّمُنِي كَلِمَاتٍ، يَنْفَعُنِي اللَّهُ بِهَا، فَخَلَّيْتُ سَبِيلَهُ‏.‏ قَالَ ‏"‏ مَا هِيَ ‏"‏‏.‏ قُلْتُ قَالَ لِي إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَاقْرَأْ آيَةَ الْكُرْسِيِّ مِنْ أَوَّلِهَا حَتَّى تَخْتِمَ ‏\{‏اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ‏\}‏ وَقَالَ لِي لَنْ يَزَالَ عَلَيْكَ مِنَ اللَّهِ حَافِظٌ وَلاَ يَقْرَبَكَ شَيْطَانٌ حَتَّى تُصْبِحَ، وَكَانُوا أَحْرَصَ شَىْءٍ عَلَى الْخَيْرِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّهُ قَدْ صَدَقَكَ وَهُوَ كَذُوبٌ، تَعْلَمُ مَنْ تُخَاطِبُ مُنْذُ ثَلاَثِ لَيَالٍ يَا أَبَا هُرَيْرَةَ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ ذَاكَ شَيْطَانٌ ‏"‏‏.‏\hadithno{2311}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) deputed me to keep Sadaqat (al-Fitr) of Ramadan. A comer came and started taking handfuls of the foodstuff (of the Sadaqa) (stealthily). I took hold of him and said, "By Allah, I will take you to Allah's Messenger (ﷺ) ." He said, "I am needy and have many dependents, and I am in great need." I released him, and in the morning Allah's Messenger (ﷺ) asked me, "What did your prisoner do yesterday?" I said, "O Allah's Messenger (ﷺ)! The person complained of being needy and of having many dependents, so, I pitied him and let him go." Allah's Messenger (ﷺ) said, "Indeed, he told you a lie and he will be coming again." I believed that he would show up again as Allah's Messenger (ﷺ) had told me that he would return. So, I waited for him watchfully. When he (showed up and) started stealing handfuls of foodstuff, I caught hold of him again and said, "I will definitely take you to Allah's Messenger (ﷺ). He said, "Leave me, for I am very needy and have many dependents. I promise I will not come back again." I pitied him and let him go. In the morning Allah's Messenger (ﷺ) asked me, "What did your prisoner do." I replied, "O Allah's Messenger (ﷺ)! He complained of his great need and of too many dependents, so I took pity on him and set him free." Allah's Apostle said, "Verily, he told you a lie and he will return." I waited for him attentively for the third time, and when he (came and) started stealing handfuls of the foodstuff, I caught hold of him and said, "I will surely take you to Allah's Messenger (ﷺ) as it is the third time you promise not to return, yet you break your promise and come." He said, "(Forgive me and) I will teach you some words with which Allah will benefit you." I asked, "What are they?" He replied, "Whenever you go to bed, recite "Ayat-al-Kursi"-- 'Allahu la ilaha illa huwa-l-Haiy-ul Qaiyum' till you finish the whole verse. (If you do so), Allah will appoint a guard for you who will stay with you and no satan will come near you till morning. " So, I released him. In the morning, Allah's Apostle asked, "What did your prisoner do yesterday?" I replied, "He claimed that he would teach me some words by which Allah will benefit me, so I let him go." Allah's Messenger (ﷺ) asked, "What are they?" I replied, "He said to me, 'Whenever you go to bed, recite Ayat-al-Kursi from the beginning to the end ---- Allahu la ilaha illa huwa-lHaiy-ul-Qaiyum----.' He further said to me, '(If you do so), Allah will appoint a guard for you who will stay with you, and no satan will come near you till morning.' (Abu Huraira or another sub-narrator) added that they (the companions) were very keen to do good deeds. The Prophet (ﷺ) said, "He really spoke the truth, although he is an absolute liar. Do you know whom you were talking to, these three nights, O Abu Huraira?" Abu Huraira said, "No." He said, "It was Satan}}
\hadithdefcmd{bukhari}{2312}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا مُعَاوِيَةُ ـ هُوَ ابْنُ سَلاَّمٍ ـ عَنْ يَحْيَى، قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَبْدِ الْغَافِرِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ جَاءَ بِلاَلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم بِتَمْرٍ بَرْنِيٍّ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِنْ أَيْنَ هَذَا ‏"‏‏.‏ قَالَ بِلاَلٌ كَانَ عِنْدَنَا تَمْرٌ رَدِيٌّ، فَبِعْتُ مِنْهُ صَاعَيْنِ بِصَاعٍ، لِنُطْعِمَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ أَوَّهْ أَوَّهْ عَيْنُ الرِّبَا عَيْنُ الرِّبَا، لاَ تَفْعَلْ، وَلَكِنْ إِذَا أَرَدْتَ أَنْ تَشْتَرِيَ فَبِعِ التَّمْرَ بِبَيْعٍ آخَرَ ثُمَّ اشْتَرِهِ ‏"‏‏.‏\hadithno{2312}\hadithtrans{Narrated Abu Sa`id al-Khudri:Once Bilal brought Barni (i.e. a kind of dates) to the Prophet (ﷺ) and the Prophet (ﷺ) asked him, "From where have you brought these?" Bilal replied, "I had some inferior type of dates and exchanged two Sas of it for one Sa of Barni dates in order to give it to the Prophet; to eat." Thereupon the Prophet (ﷺ) said, "Beware! Beware! This is definitely Riba (usury)! This is definitely Riba (Usury)! Don't do so, but if you want to buy (a superior kind of dates) sell the inferior dates for money and then buy the superior kind of dates with that money}}
\hadithdefcmd{bukhari}{2313}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ فِي صَدَقَةِ عُمَرَ ـ رضى الله عنه ـ لَيْسَ عَلَى الْوَلِيِّ جُنَاحٌ أَنْ يَأْكُلَ وَيُؤْكِلَ صَدِيقًا ‏\{‏لَهُ‏\}‏ غَيْرَ مُتَأَثِّلٍ مَالاً، فَكَانَ ابْنُ عُمَرَ هُوَ يَلِي صَدَقَةَ عُمَرَ يُهْدِي لِلنَّاسِ مِنْ أَهْلِ مَكَّةَ، كَانَ يَنْزِلُ عَلَيْهِمْ‏.‏\hadithno{2313}\hadithtrans{Narrated `Amr:Concerning the Waqf of `Umar: It was not sinful of the trustee (of the Waqf) to eat or provide his friends from it, provided the trustee had no intention of collecting fortune (for himself). Ibn `Umar was the manager of the trust of `Umar and he used to give presents from it to those with whom he used to stay at Mecca}}
\hadithdefcmd{bukhari}{2315}{حَدَّثَنَا أَبُو الْوَلِيدِ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ، وَأَبِي، هُرَيْرَةَ رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَاغْدُ يَا أُنَيْسُ إِلَى امْرَأَةِ هَذَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏\hadithno{2315}\hadithtrans{Narrated Zaid bin Khalid and Abu Huraira:The Prophet (ﷺ) said, "O Unais! Go to the wife of this (man) and if she confesses (that she has committed illegal sexual intercourse), then stone her to death}}
\hadithdefcmd{bukhari}{2316}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ جِيءَ بِالنُّعَيْمَانِ أَوِ ابْنِ النُّعَيْمَانِ شَارِبًا، فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ كَانَ فِي الْبَيْتِ أَنْ يَضْرِبُوا قَالَ فَكُنْتُ أَنَا فِيمَنْ ضَرَبَهُ، فَضَرَبْنَاهُ بِالنِّعَالِ وَالْجَرِيدِ‏.‏\hadithno{2316}\hadithtrans{Narrated `Uqba bin Al-Harith:When An-Nuaman or his son was brought in a state of drunkenness, Allah's Messenger (ﷺ) ordered all those who were present in the house to beat him. I was one of those who beat him. We beat him with shoes and palm-leaf stalks}}
\hadithdefcmd{bukhari}{2317}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ قَالَتْ، عَائِشَةُ ـ رضى الله عنها ـ أَنَا فَتَلْتُ، قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَدَىَّ، ثُمَّ قَلَّدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدَيْهِ، ثُمَّ بَعَثَ بِهَا مَعَ أَبِي، فَلَمْ يَحْرُمْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم شَىْءٌ أَحَلَّهُ اللَّهُ لَهُ حَتَّى نُحِرَ الْهَدْىُ‏.‏\hadithno{2317}\hadithtrans{Narrated `Aisha:I twisted the garlands of the Hadis (i.e. animals for sacrifice) of Allah's Messenger (ﷺ) with my own hands. Then Allah's Messenger (ﷺ) put them around their necks with his own hands, and sent them with my father (to Mecca). Nothing legal was regarded illegal for Allah's Messenger (ﷺ) till the animals were slaughtered}}
\hadithdefcmd{bukhari}{2318}{حَدَّثَنِي يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ الأَنْصَارِ بِالْمَدِينَةِ مَالاً، وَكَانَ أَحَبَّ أَمْوَالِهِ إِلَيْهِ بِيْرُ حَاءَ وَكَانَتْ مُسْتَقْبِلَةَ الْمَسْجِدَ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ فَلَمَّا نَزَلَتْ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، إِنَّ اللَّهَ تَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بِيْرُ حَاءَ، وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ شِئْتَ، فَقَالَ ‏"‏ بَخٍ، ذَلِكَ مَالٌ رَائِحٌ، ذَلِكَ مَالٌ رَائِحٌ‏.‏ قَدْ سَمِعْتُ مَا قُلْتَ فِيهَا، وَأَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ قَالَ أَفْعَلُ يَا رَسُولَ اللَّهِ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ‏.‏ تَابَعَهُ إِسْمَاعِيلُ عَنْ مَالِكٍ‏.‏ وَقَالَ رَوْحٌ عَنْ مَالِكٍ رَابِحٌ‏.‏\hadithno{2318}\hadithtrans{Narrated Anas bin Malik:Abu Talha was the richest man in Medina amongst the Ansar and Beeruha' (garden) was the most beloved of his property, and it was situated opposite the mosque (of the Prophet.). Allah's Messenger (ﷺ) used to enter it and drink from its sweet water. When the following Divine Verse was revealed: 'You will not attain righteousness till you spend in charity of the things you love' (3.92), Abu Talha got up in front of Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Allah says in His Book, 'You will not attain righteousness unless you spend (in charity) that which you love,' and verily, the most beloved to me of my property is Beeruha (garden), so I give it in charity and hope for its reward from Allah. O Allah's Apostle! Spend it wherever you like." Allah's Messenger (ﷺ) appreciated that and said, "That is perishable wealth, that is perishable wealth. I have heard what you have said; I suggest you to distribute it among your relatives." Abu Talha said, "I will do so, O Allah's Messenger (ﷺ)." So, Abu Talha distributed it among his relatives and cousins. The sub-narrator (Malik) said: The Prophet (ﷺ) said: "That is a profitable wealth," instead of "perishable wealth}}
\hadithdefcmd{bukhari}{2319}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَازِنُ الأَمِينُ الَّذِي يُنْفِقُ ـ وَرُبَّمَا قَالَ الَّذِي يُعْطِي ـ مَا أُمِرَ بِهِ كَامِلاً مُوَفَّرًا، طَيِّبٌ نَفْسُهُ، إِلَى الَّذِي أُمِرَ بِهِ، أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏‏.‏\hadithno{2319}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "An honest treasurer who gives what he is ordered to give fully, perfectly and willingly to the person to whom he is ordered to give, is regarded as one of the two charitable persons}}
